#
# spec file for package surfraw
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Requires perl-WWW-OpenSearch not in factory
%bcond_with     elvi_opensearch

Name:           surfraw
Version:        2.3.0
Release:        4.2
Summary:        Command Line Interface to WWW Search Engines
License:        SUSE-Public-Domain
Group:          Productivity/Networking/Web/Browsers
URL:            https://gitlab.com/surfraw/Surfraw
Source:         https://gitlab.com/surfraw/Surfraw/uploads/2de827b2786ef2fe43b6f07913ca7b7f/%{name}-%{version}.tar.gz
Patch0:         test-show-failing-url.patch
# PATCH-FIX-UPSTREAM
Patch1:         reproducible.patch
BuildRequires:  make
BuildRequires:  perl-HTML-Parser
BuildRequires:  perl-LWP-Protocol-https
BuildRequires:  perl-libwww-perl
%if %{with elvi_opensearch}
BuildRequires:  perl-WWW-OpenSearch
%endif
BuildRequires:  sed
BuildRequires:  w3m
BuildRequires:  wget
Requires:       sed
Requires:       w3m
Requires:       xdg-utils
BuildArch:      noarch

%description
Surfraw provides a Unix command line interface to a variety of
WWW search engines and other artifacts of information and makes
them available as extensions to the shell.
Surfraw abstracts the browser away from input. Interpretation of
linguistic forms is handed back to the shell.

%if %{with elvi_opensearch}
%package opensearch
Summary:        Surfraw OpenSearch support
Group:          Productivity/Networking/Web/Browsers
Requires:       %{name} = %{version}
Requires:       perl-HTML-Parser
Requires:       perl-LWP-Protocol-https
Requires:       perl-WWW-OpenSearch
Requires:       perl-libwww-perl

%description opensearch
Surfraw OpenSearch provides opensearch support.
%endif

%prep
%autosetup -p1

chmod a+x elvi/phpdoc

%build
%configure --libdir=%{_libexecdir} \
%if %{without elvi_opensearch}
            --disable-opensearch \
%endif
            --with-text-browser=w3m \
            --with-graphical-browser=xdg-open
make %{?_smp_mflags}

%install
%make_install
# These depend on apt-cache
rm %{buildroot}/%{_libexecdir}/%{name}/debpkghome
rm %{buildroot}/%{_libexecdir}/%{name}/debvcsbrowse

%check
# Several elvi fail trying to re-use elvi duckduckgo and google , resulting in
# Get failed: 501 Protocol scheme 'surfraw' is not supported
# as it is trying to fetch `surfraw: duckduckgo: No elvis or bookmark with that name`
mkdir -p $HOME/.config/surfraw/elvi
cp elvi/duckduckgo $HOME/.config/surfraw/elvi
cp elvi/google $HOME/.config/surfraw/elvi

rm test/debpkghome.test
rm test/debvcsbrowse.test

export BROWSER=echo
export PATH=${PWD}/%{buildroot}/%{_libexecdir}/%{name}:$PATH
./test/runtests

%files
%doc AUTHORS ChangeLog HACKING NEWS TODO surfraw.lsm
%license COPYING
%{_bindir}/sr
%{_bindir}/%{name}
%{_bindir}/surfraw-update-path
%dir %{_sysconfdir}/xdg/%{name}
%config(noreplace) %{_sysconfdir}/xdg/%{name}/bookmarks
%config(noreplace) %{_sysconfdir}/xdg/%{name}/conf
%exclude %{_libexecdir}/%{name}/woffle
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/*
%exclude %{_mandir}/man1/opensearch-* 
%{_mandir}/man1/*.1*

%if %{with elvi_opensearch}
%files opensearch
%license COPYING
%{_bindir}/opensearch*
%{_mandir}/man1/opensearch-* 
%endif

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Aug 13 2021 Sébastien Poher <sogal@opensuse.org>
- Make surfraw independent from htdig (remove woffle subpackage)
  as htdig does not seem to be maintained anymore
* Tue Jun 11 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Sat Mar 30 2019 John Vandenberg <jayvdb@gmail.com>
- Create subpackages for opensearch and woffle as they have
  different dependencies, with opensearch disabled due to
  dependencies not in factory
- Fix elvi phpdoc which wasnt executable
- Add missing dependencies
- Activate the tests.  While they mostly fail due to no internet,
  they are useful to spot missing dependencies.
- Remove two elvi which depend on apt-cache, suited for Debian systems
- Remove /etc/xdg from directories owned by this package
- Add test-show-failing-url.patch for debugging purpose
* Thu Mar 22 2018 sogal@volted.net
- specfile cleaned
  * remove redefinition of libdir
  * fix elvis location
  * remove uneeded build dependencies
  * use only xdg to define browser
- pkg meta changed to ensure neutrality of description
* Tue Mar 20 2018 jengelh@inai.de
- Ensure neutrality of description.
* Wed Mar 14 2018 sogal@volted.net
- Updated to 2.3.0
  * Source moved to https://gitlab.com/surfraw/Surfraw
  * All elvi now use HTTPS
  * Elvi for sites that don't work with HTTPS have left the building
  * Select Perl version at buildtime (Mark Meyer)
  * Remove lynx-cur (closes #882286)
  * Sundry bug fixes, new hacking style guide and other goodness
* Wed Jan  3 2018 sogal@volted.net
- Updated to 2.2.9. Too many changes since 2.2.4,
  see http://surfraw.alioth.debian.org
  * Specfile cleaned
  * opensearch disabled in configure to remove dependencies to perl-WWW-OpenSearch
  packages (devel:languages:perl repo required otherwise).
* Thu Mar 12 2009 Pascal Bleser <pascal.bleser@opensuse.org> 2.2.4
- use firefox instead of xdg-open for graphical browsing on < 10.2 (and SLE),
  as those versions don't ship xdg-open
- update to 2.2.4:
  * new search tools were added: ntrs (NASA Tech Reports), scicom (Scientific
    Commons), springer (journals and books), urban (Urban Dictionary), and aur
    (ArchLinux User Repository)
  * the excite, cite, and amazon tools were fixed
* Sun Sep 14 2008 Pascal Bleser <guru@unixtech.be> 2.2.3
- update to 2.2.3:
  * surfraw now defaults to graphical mode; the surfraw(1) man page explains
    how to change the default back
  * default browsers are now detected during build; to override this, use the
  - -with-text-browser=BROWSER --with-graphical-browser=BROWSER options of
    the ./configure script
  * new search tools were added: genportage
  * various small fixes were made
* Tue Jul  8 2008 Pascal Bleser <guru@unixtech.be> 2.2.2
- new package
